Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `eggbasket`
  - `config`
  - `odict`: A dict that keeps keys in insertion order
  - `release`: A simple, lightweight Python Package Index (aka Cheeseshop) clone.
  - `rest`: rest-to-html conversion taken from the Zope core This implementation requires docutils 0.4.0+ from http://docutils.sf.net/
  - `templates`
  - `tests`

## Class Hierarchy

- `__builtin__.object`: The most base type
  - `__builtin__.dict`: dict() -> new empty dictionary.
    - `eggbasket.odict.OrderedDict`: A class of dictionary that keeps the insertion order of keys.
      - `eggbasket.odict.SequenceOrderedDict`: Experimental version of OrderedDict that has a custom object for `keys`, `values`, and `items`.
  - `__builtin__.type`: type(object) -> the object's type type(name, bases, dict) -> a new type
  - `eggbasket.odict.Items`: Custom object for accessing the items of an OrderedDict.
  - `eggbasket.odict.Keys`: Custom object for accessing the keys of an OrderedDict.
  - `eggbasket.odict.Values`: Custom object for accessing the values of an OrderedDict.
- `eggbasket.rest.Warnings`

Generated by Epydoc 2.1 on Mon Apr 21 14:16:57 2008 | http://epydoc.sf.net